Documentation
¶
Overview ¶
Package wedit provides the server backend for a game world editor. We originally had separate maped and chared, which unified code in gamed. Now that we want to import the old editor data, we need a new package to avoid an import cycle. We should later moved code from gamed into the editor package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Editor ¶
type Editor struct {
// The world data that is saved to disk.
bolt.WorldSync
// Conns holds a list of clients connected to this editor.
site.Conns
// Tops stores all topics and the clients that are subscribed to them.
Tops map[Top]*TopicSubs
}
Editor provides the world data and ways to edit this data. It also holds client subscriptions for certain topics.
type Room ¶
type RoomSubs ¶
func MakeRoomSubs ¶
func MakeRoomSubs() RoomSubs
type SliceReq ¶
Click to show internal directories.
Click to hide internal directories.